@@ -1,12 +1,11 @@
 
-
 #' Bathrooms by dates
 #'
 #' Requests all records on bathrooms created or updated on or after a
 #' given date.
 #'
 #' @param date A date in "yyyy-mm-dd" format, or any format that can be
-#' coerced to a date with \code{as.Date()}.
+#' coerced to a date with `as.Date()`.
 #'
 #' @inheritParams rfg_all_restrooms
 #'
@@ -20,9 +19,8 @@
 #'
 #' }
 
-
 rfg_date <- function(date = NULL, accessible = FALSE,
-                     unisex = FALSE, verbose = TRUE) {
+                     unisex = FALSE, verbose = TRUE, tidy = FALSE) {
   if (is.null(date)) stop("Please enter a date", call. = FALSE)
 
   date <- as.Date(date)
@@ -37,7 +35,7 @@ rfg_date <- function(date = NULL, accessible = FALSE,
     "&year=", format(date, "%y"), "&per_page=1"
   )
 
-  df <- query_looper(query, verbose)
+  df <- query_looper(query, verbose, tidy)
 
   df
 }
